@@ -6,6 +6,12 @@ our (%gui);
 # Error Dialog Block
 {
     my %err = (
+        exportapplusb      => ['Appliance Export Error',
+                               'This guest has USB attached storage which is not supported by appliances.',
+                               'error'],
+        encdiskpasswd      => ['Encryption Password Mismatch',
+                               'Disk encyption settings have not been changed because there was a password mismatch.',
+                               'error'],
         invalidname        => ['Invalid Name',
                                'An invalid or blank name has been entered.',
                                'error'],
@@ -28,7 +34,7 @@ our (%gui);
                                'An invalid CIDR network has been entered.',
                                'error'],
         connect       => ['Failed to Connect',
-                          'Credentials are incorrect or the VirtualBox Web Service is not running at the specified URL.',
+                          ' ',
                           'error'],
         applimport    => ['Failed Appliance Import',
                           'The appliance failed to import correctly. The file may be missing, corrupt, have incorrect' .
@@ -50,14 +56,14 @@ our (%gui);
                           'This controller is full, no more media can be attached.',
                           'warning'],
         deletemedium  => ['Cannot Delete Medium',
-                          'The medium is in a state which does not permit deletion.' . 
+                          'The medium is in a state which does not permit deletion.' .
                           ' It may be locked by another process.',
                           'warning'],
         existattach   => ['Port and Device In Use',
                           'Device port already has a medium attached to it.',
                           'warning'],
         mediuminuse   => ['Medium In Use',
-                          'The medium could not be released from at least one guest.' . 
+                          'The medium could not be released from at least one guest.' .
                           ' This is because the guest is currently in use.',
                           'warning'],
         noextensions  => ['Oracle VM VirtualBox Extension Pack',
@@ -176,4 +182,19 @@ sub vboxerror {
     }
 }
 
+# Call back only when a logon is attempted. A bit of a hack but tries to differentiate beyween
+# a failed logon due to credentials, or the service / hostname is incorrect.
+sub vboxlogonerror {
+        my ($soap, $res) = @_;
+
+        if ($soap->transport->status =~ m/internal server error/i) {
+            &show_err_msg('connect', 'Login Denied. Please check your login credentials.');
+        }
+        else {
+            &show_err_msg('connect', $soap->transport->status);
+        }
+        $gui{websn} = undef; # Invalidate current session to prevent deep recursion
+        &virtualbox_logoff(1); # Cleanup - but logoff will not happen because session is invalidated
+}
+
 1;
