@@ -3,7 +3,7 @@ use strict;
 use warnings;
 our (%gui, %signal, %vmc);
 
-sub setup_edit_dialog_storage() {
+sub setup_edit_dialog_storage {
     my $vhost = &vhost();
     &addrow_log("Fetching storage settings for $vmc{Name}...");
     &busy_pointer($gui{dialogEdit}, 1);
@@ -105,7 +105,7 @@ sub setup_edit_dialog_storage() {
 }
 
 # Displays the create a new hard disk dialog. Creates & attaches based on options
-sub show_dialog_createhd() {
+sub show_dialog_createhd {
     my $vhost = &vhost();
     my $guestname = IMachine_getName($vmc{IMachine});
     $gui{comboboxCreateHDFormat}->set_active(0);
@@ -150,7 +150,7 @@ sub show_dialog_createhd() {
 
 # Handle the radio button sensitivity when selecting an image format when
 # creating a hard disk
-sub sens_createhdformat() {
+sub sens_createhdformat {
     my $format = &getsel_combo($gui{comboboxCreateHDFormat}, 1);
     $gui{radiobuttonCreateHDDynamic}->set_active(1);
 
@@ -172,7 +172,7 @@ sub sens_createhdformat() {
 }
 
 # Adds a storage controller to the guest
-sub storage_ctr_add() {
+sub storage_ctr_add {
     my ($widget) = @_;
     my $bus = 'Floppy'; # Assume floppy unless set otherwise
 
@@ -199,7 +199,7 @@ sub storage_ctr_add() {
 }
 
 # Attaches a hard disk to a controller
-sub storage_attach_hd() {
+sub storage_attach_hd {
     my ($widget, $IMedium) = @_;
     my $storref = &getsel_list_editstorage();
     my $attached = 0;
@@ -219,7 +219,7 @@ sub storage_attach_hd() {
 }
 
 # Attaches a DVD to a controller or DVD image to DVD ROM
-sub storage_attach_dvd() {
+sub storage_attach_dvd {
     my ($widget, $IMedium) = @_;
     my $storref = &getsel_list_editstorage();
     my $attached = 0;
@@ -244,7 +244,7 @@ sub storage_attach_dvd() {
 }
 
 # Attaches a floppy to a controller
-sub storage_attach_floppy() {
+sub storage_attach_floppy {
     my ($widget, $IMedium) = @_;
     my $storref = &getsel_list_editstorage();
     my $attached = 0;
@@ -268,7 +268,7 @@ sub storage_attach_floppy() {
 }
 
 # Detaches a storage unit or ejects removable media
-sub storage_attach_rem() {
+sub storage_attach_rem {
     my $storref = &getsel_list_editstorage();
 
     if ((($$storref{MediumType} eq 'Floppy') or ($$storref{MediumType} eq 'DVD')) and $$storref{IMedium}) {
@@ -280,7 +280,7 @@ sub storage_attach_rem() {
 }
 
 # Removes a controller from the guest
-sub storage_ctr_rem() {
+sub storage_ctr_rem {
     my $storref = &getsel_list_editstorage();
     my @IMediumAttachments = IMachine_getMediumAttachmentsOfController($vmc{IMachine}, $$storref{ControllerName});
 
@@ -291,50 +291,50 @@ sub storage_ctr_rem() {
 }
 
 # Sets the controller variant type
-sub storage_ctrtype() {
+sub storage_ctrtype {
     my $storref = &getsel_list_editstorage();
     IStorageController_setControllerType($$storref{IStorageController}, &getsel_combo($gui{comboboxEditStorCtrType}, 0));
 }
 
 # Set / Clear the host I/O cache for the controller
-sub storage_ctrcache() {
+sub storage_ctrcache {
     my $storref = &getsel_list_editstorage();
     IStorageController_setUseHostIOCache($$storref{IStorageController}, $gui{checkbuttonEditStorCache}->get_active());
 }
 
-sub show_attach_menu() {
+sub show_attach_menu {
     my ($widget, $event) = @_;
     $gui{menuAttachAdd}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
     return 0;
 }
 
-sub show_ctr_menu() {
+sub show_ctr_menu {
     my ($widget, $event) = @_; #$event->time
     $gui{menuCtrAdd}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
     return 0;
 }
 
 # Sets a specific port count if manually set by the user
-sub storage_port_count() {
+sub storage_port_count {
     my $storref = &getsel_list_editstorage();
     my $pc = int($gui{adjustmentEditStorPortCount}->get_value());
     IStorageController_setPortCount($$storref{IStorageController}, $pc);
 }
 
 # Flags a hard disk image as being SSD
-sub storage_ssd() {
+sub storage_ssd {
     my $storref = &getsel_list_editstorage();
     IMachine_nonRotationalDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device}, $gui{checkbuttonEditStorSSD}->get_active());
 }
 
 # Flags whether a CD/DVD is allowed to be temporary ejected (ie Live CD)
-sub storage_livecd() {
+sub storage_livecd {
     my $storref = &getsel_list_editstorage();
     IMachine_temporaryEjectDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device}, $gui{checkbuttonEditStorLive}->get_active());
 }
 
 # Moves an attachment to a new port
-sub storage_connected_port() {
+sub storage_connected_port {
     my $newdevice = &getsel_combo($gui{comboboxEditStorDevPort}, 1);
     my $newport = &getsel_combo($gui{comboboxEditStorDevPort}, 2);
     my $storref = &getsel_list_editstorage();
@@ -366,7 +366,7 @@ sub storage_connected_port() {
 }
 
 # Handles the sensitive if a SATA controller is selected
-sub sens_editstor_sata_ctr() {
+sub sens_editstor_sata_ctr {
     $gui{labelEditStorPortCount}->show();
     $gui{spinbuttonEditStorPortCount}->show();
     $gui{menuitemAttachHD}->set_sensitive(1);
@@ -374,19 +374,19 @@ sub sens_editstor_sata_ctr() {
     $gui{menuitemAttachFloppy}->set_sensitive(0);
 }
 
-sub sens_editstor_ctr() {
+sub sens_editstor_ctr {
     $gui{menuitemAttachHD}->set_sensitive(1);
     $gui{menuitemAttachDVD}->set_sensitive(1);
     $gui{menuitemAttachFloppy}->set_sensitive(0);
 }
 
-sub sens_editstor_floppy_ctr() {
+sub sens_editstor_floppy_ctr {
     $gui{menuitemAttachHD}->set_sensitive(0);
     $gui{menuitemAttachDVD}->set_sensitive(0);
     $gui{menuitemAttachFloppy}->set_sensitive(1);
 }
 
-sub sens_editstor_allctr() {
+sub sens_editstor_allctr {
     $gui{frameEditStorAttr}->show();
     $gui{buttonEditStorAddAttach}->set_sensitive(1);
     $gui{buttonEditStorRemoveAttach}->set_sensitive(0);
@@ -405,7 +405,7 @@ sub sens_editstor_allctr() {
 }
 
 # Handle widget sensitivity specify to HD media selection
-sub sens_editstor_hd() {
+sub sens_editstor_hd {
     $gui{buttonEditStorAddAttach}->set_sensitive(0);
     $gui{checkbuttonEditStorSSD}->show();
     $gui{checkbuttonEditStorLive}->hide();
@@ -415,7 +415,7 @@ sub sens_editstor_hd() {
 }
 
 # Handle widget sensitivity specify to DVD media selection
-sub sens_editstor_dvd() {
+sub sens_editstor_dvd {
     $gui{buttonEditStorAddAttach}->set_sensitive(1);
     $gui{checkbuttonEditStorSSD}->hide();
     $gui{checkbuttonEditStorLive}->show();
@@ -425,7 +425,7 @@ sub sens_editstor_dvd() {
 }
 
 # Handle widget sensitivity specify to floppy media selection
-sub sens_editstor_floppy() {
+sub sens_editstor_floppy {
     $gui{buttonEditStorAddAttach}->set_sensitive(1);
     $gui{checkbuttonEditStorSSD}->hide();
     $gui{checkbuttonEditStorLive}->hide();
@@ -435,7 +435,7 @@ sub sens_editstor_floppy() {
 }
 
 # Handle widget sensitivity common to all media selection
-sub sens_editstor_allmedia() {
+sub sens_editstor_allmedia {
     $gui{frameEditStorAttr}->show();
     $gui{buttonEditStorRemoveAttach}->set_sensitive(1);
     $gui{buttonEditStorRemoveCtr}->set_sensitive(0);
@@ -451,11 +451,11 @@ sub sens_editstor_allmedia() {
 }
 
 # Sets the sensitive of widgets if no storage item is selected
-sub sens_editstor_nosel() {
+sub sens_editstor_nosel {
     $gui{frameEditStorAttr}->hide(); # Hides all the attributed widgets in one go
     $gui{buttonEditStorAddAttach}->set_sensitive(0);
     $gui{buttonEditStorRemoveAttach}->set_sensitive(0);
     $gui{buttonEditStorRemoveCtr}->set_sensitive(0);
 }
 
-1;
\ No newline at end of file
+1;
