@@ -3,7 +3,7 @@ use strict;
 use warnings;
 our (%gui);
 
-sub show_dialog_vmm() {
+sub show_dialog_vmm {
     &addrow_log('Retrieving global media information...');
     &busy_window($gui{windowMain}, 0, 'watch');
     &fill_list_vmmhd();
@@ -16,7 +16,7 @@ sub show_dialog_vmm() {
 }
 
 # Handles GUI changes when user selects a different tab
-sub vmm_tabchanged() {
+sub vmm_tabchanged {
     my ($widget, $focus, $page) = @_;
 
     # Reset widgets as they are evaluated later
@@ -38,7 +38,7 @@ sub vmm_tabchanged() {
 }
 
 # Releases a medium from a guest
-sub vmm_release() {
+sub vmm_release {
     my $mediumref;
     my $page = $gui{notebookVMM}->get_current_page();
     my $warn = 0;
@@ -59,7 +59,7 @@ sub vmm_release() {
 
                 if ($page == 0) { # We have a HD
                     if ($$sref{Type} eq 'WriteLock') { # Cannot do it if it's a shared lock
-                        IMachine_detachDevice($$sref{IMachine}, $$attach{controller}, $$attach{port}, $$attach{device});    
+                        IMachine_detachDevice($$sref{IMachine}, $$attach{controller}, $$attach{port}, $$attach{device});
                     }
                     else { $warn = 1; }
                 }
@@ -81,7 +81,7 @@ sub vmm_release() {
     else { &fill_list_vmmfloppy(); }
 }
 
-sub vmm_rem() {
+sub vmm_rem {
     my $page = $gui{notebookVMM}->get_current_page();
 
     if ($page == 0) {
@@ -121,7 +121,7 @@ sub vmm_rem() {
 }
 
 # Adds a harddisk/dvd/floppy image to the VMM
-sub vmm_add() {
+sub vmm_add {
     my ($location, $filearrayref) = @_;
     my $page = $gui{notebookVMM}->get_current_page();
     return if (!$location);
@@ -159,7 +159,7 @@ sub vmm_add() {
 }
 
 # Refreshes the media on the currently selected page
-sub vmm_refresh() {
+sub vmm_refresh {
     my $page = $gui{notebookVMM}->get_current_page();
 
     if ($page == 0) { &fill_list_vmmhd(); }
@@ -168,7 +168,7 @@ sub vmm_refresh() {
 }
 
 # Displays the modify medium window
-sub show_vmm_modify() {
+sub show_vmm_modify {
     my $hdref = &getsel_list_vmmhd();
     $gui{labelVMMModifySubTitle}->set_text('Modifying: ' . $$hdref{Name});
     &combobox_set_active_text($gui{comboboxVMMModifyType}, $$hdref{Type});
@@ -185,7 +185,7 @@ sub show_vmm_modify() {
 }
 
 # Displays the copy HD medium window
-sub show_vmm_copy() {
+sub show_vmm_copy {
     my $hdref = &getsel_list_vmmhd();
     my $newdiskname = $$hdref{Name};
     $newdiskname =~ s/\.vdi$//i;
@@ -202,7 +202,7 @@ sub show_vmm_copy() {
 
     do {
         my $response = $gui{dialogCopyHD}->run;
-    
+
         if ($response eq 'ok') {
             # No validation needed for other entries
             if (!$gui{entryCopyHDName}->get_text()) { &show_err_msg('invalidname', '(New Disk Name)'); }
@@ -224,7 +224,7 @@ sub show_vmm_copy() {
 }
 
 # Handles the copying and converting of hard disks after the location is chosen
-sub handle_copyhdfilechooser() {
+sub handle_copyhdfilechooser {
     my ($location, $file) = @_;
     my $variant = 'Standard'; # Standard is Dynamic
 
@@ -254,7 +254,7 @@ sub handle_copyhdfilechooser() {
 }
 
 # Handle the radio button sensitivity when selecting an image format for copying
-sub sens_copyhdformat() {
+sub sens_copyhdformat {
     my $format = &getsel_combo($gui{comboboxCopyHDFormat}, 1);
     $gui{radiobuttonCopyHDDynamic}->set_active(1);
 
@@ -275,14 +275,18 @@ sub sens_copyhdformat() {
     }
 }
 
+# Run when there are no devices selected in the VMM and between tab changes
 sub vmm_sens_unselected {
-    $gui{labelVMMTypeField}->set_text(''); 
-    $gui{labelVMMAttachedToField}->set_text(''); 
+    $gui{labelVMMTypeField}->set_text('');
+    $gui{labelVMMAttachedToField}->set_text('');
     $gui{labelVMMLocationField}->set_text('');
+    $gui{labelVMMEncryptedField}->set_text('');
+    $gui{labelVMMUUIDField}->set_text('');
+
     $gui{toolbuttonVMMRemove}->set_sensitive(0);
     $gui{toolbuttonVMMCopy}->set_sensitive(0);
     $gui{toolbuttonVMMModify}->set_sensitive(0);
     $gui{toolbuttonVMMRelease}->set_sensitive(0);
 }
 
-1;
\ No newline at end of file
+1;
