@@ -71,7 +71,7 @@ our (%gui, %vmc, %signal, %prefs);
             my $bdev = IMachine_getBootOrder($$gref{IMachine}, $_);
         $bootorder .= "$bdev  " if ($bdev ne 'Null');
         }
-    
+
         $bootorder ? &addrow_details($sysiter, 1, ' Boot Order:', 2, $bootorder) : &addrow_details($sysiter, 1, ' Boot Order:', 2, '<None Enabled>');
         my $vtx = '';
         $vtx .= 'VT-x/AMD-V  ' if (IMachine_getHWVirtExProperty($$gref{IMachine}, 'Enabled') eq 'true');
@@ -103,7 +103,8 @@ our (%gui, %vmc, %signal, %prefs);
                     IMedium_refreshState($$attachment{medium}); # Needed to bring in current sizes
                     # Use the base medium for information purposes
                     my $size = &bytesToX(IMedium_getLogicalSize($$attachment{medium}));
-                    &addrow_details($storiter, 1, "   Port $$attachment{port}:", 2, IMedium_getName(IMedium_getBase($$attachment{medium})) . " ($$attachment{type}, $size)");
+                    my $encrypted = &imedium_has_property($$attachment{medium}, 'CRYPT/KeyStore') ? 'Encrypted ' : '';
+                    &addrow_details($storiter, 1, "   Port $$attachment{port}:", 2, IMedium_getName(IMedium_getBase($$attachment{medium})) . " ( $$attachment{type} $size $encrypted)");
                 }
             }
         }
@@ -138,10 +139,10 @@ our (%gui, %vmc, %signal, %prefs);
         my $ioiter = &addrow_details(undef, 0, $gui{img}{CatIO}, 1, 'I/O Ports', 3, 800, 4, 0.0, 5, 'EXPANDDETIO');
         foreach (0..($$vhost{maxser}-1)) {
             my $ISerialPort = IMachine_getSerialPort($$gref{IMachine}, $_);
-            ISerialPort_getEnabled($ISerialPort) eq 'true' ? &addrow_details($ioiter, 1, " Serial Port #$_:", 2, 'Enabled  ' . 
+            ISerialPort_getEnabled($ISerialPort) eq 'true' ? &addrow_details($ioiter, 1, " Serial Port #:" . ($_ + 1), 2, 'Enabled  ' .
                                                                                             ISerialPort_getHostMode($ISerialPort) . '  ' .
                                                                                             ISerialPort_getPath($ISerialPort))
-                                                        : &addrow_details($ioiter, 1, " Serial Port #$_:", 2, 'Disabled');
+                                                        : &addrow_details($ioiter, 1, " Serial Port #:" . ($_ + 1), 2, 'Disabled');
         }
 
         my $IParallelPort = IMachine_getParallelPort($$gref{IMachine}, 0);
@@ -154,7 +155,7 @@ our (%gui, %vmc, %signal, %prefs);
             foreach my $usbcontroller (@IUSBController) {
                 my $usbver = IUSBController_getUSBStandard($usbcontroller);
                 &addrow_details($usbiter, 1, ' Controller:',
-                                        2, IUSBController_getName($usbcontroller) . 
+                                        2, IUSBController_getName($usbcontroller) .
                                         ' (' . IUSBController_getType($usbcontroller) . ')');
             }
 
@@ -206,7 +207,7 @@ sub addrow_details {
 
 # Fills the remote file chooser with a list of files. Involves a lot of splicing because
 # of the crazy way VirtualBox returns a file list
-sub fill_list_remotefiles() {
+sub fill_list_remotefiles {
     &busy_pointer($gui{dialogRemoteFileChooser}, 1);
     my ($location, $filter) = @_;
     my $vhost = &vhost();
@@ -260,13 +261,13 @@ sub fill_list_remotefiles() {
 }
 
 # Fills a list as returned from reading the remote log file
-sub fill_list_log() {
+sub fill_list_log {
     my ($IMachine) = @_;
     $gui{liststoreLog0}->clear();
     $gui{liststoreLog1}->clear();
     $gui{liststoreLog2}->clear();
     $gui{liststoreLog3}->clear();
-    
+
     for my $lognum (0..3) {
         my $log;
         my $offset = 0;
@@ -283,7 +284,7 @@ sub fill_list_log() {
 
             if ($log) {
                 my @logarr = split "\n", $log; # Do we need to include windows/mac EOL here?
-            
+
                 foreach (0..$#logarr) {
                     $logarr[$_] =~ s/\r//g;
                     my $iter = $gui{'liststoreLog' . $lognum}->append;
@@ -304,7 +305,7 @@ sub fill_list_log() {
 }
 
 # Fills a list of basic information about the remote server
-sub fill_list_serverinfo() {
+sub fill_list_serverinfo {
     $gui{liststoreInfo}->clear();
     my $vhost = &vhost();
     &addrow_info(0, 'URL:', 1, $endpoint);
@@ -344,14 +345,14 @@ sub fill_list_editshared {
     my @ISharedFolderTran = IConsole_getSharedFolders($IConsole) if ($IConsole);
     $gui{buttonEditSharedRemove}->set_sensitive(0);
     $gui{buttonEditSharedEdit}->set_sensitive(0);
-    $gui{liststoreEditShared}->clear(); 
+    $gui{liststoreEditShared}->clear();
 
     foreach (@ISharedFolderPerm) { &addrow_editshared($_, 'Yes'); }
     foreach (@ISharedFolderTran) { &addrow_editshared($_, 'No'); }
 }
 
 # Populates the guest's storage list
-sub fill_list_editstorage() {
+sub fill_list_editstorage {
     my ($IMachine) = @_;
     &busy_pointer($gui{dialogEdit}, 1);
     &sens_editstor_nosel();
@@ -429,9 +430,9 @@ sub fill_list_editstorage() {
 {
     my %selected = (INATNetwork => '');
 
-    sub getsel_list_vbprefsnat() { return \%selected; }
+    sub getsel_list_vbprefsnat { return \%selected; }
 
-    sub fill_list_vbprefsnat() {
+    sub fill_list_vbprefsnat {
         &busy_pointer($gui{dialogVBPrefs}, 1);
         $gui{buttonVBPrefsDelNAT}->set_sensitive(0);
         $gui{buttonVBPrefsEditNAT}->set_sensitive(0);
@@ -453,7 +454,7 @@ sub fill_list_editstorage() {
         &busy_pointer($gui{dialogVBPrefs}, 0);
     }
 
-    sub onsel_list_vbprefsnat() {
+    sub onsel_list_vbprefsnat {
         my $model = $gui{treeviewVBPrefsNAT}->get_model();
         my $iter = $gui{treeviewVBPrefsNAT}->get_selection->get_selected() ? $gui{treeviewVBPrefsNAT}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -467,9 +468,9 @@ sub fill_list_editstorage() {
 {
     my %selected = (Uuid => '');
 
-    sub getsel_list_vbprefshon() { return \%selected; }
+    sub getsel_list_vbprefshon { return \%selected; }
 
-    sub fill_list_vbprefshon() {
+    sub fill_list_vbprefshon {
         &busy_pointer($gui{dialogVBPrefs}, 1);
         $gui{buttonVBPrefsDelHON}->set_sensitive(0);
         $gui{buttonVBPrefsEditHON}->set_sensitive(0);
@@ -493,7 +494,7 @@ sub fill_list_editstorage() {
         &busy_pointer($gui{dialogVBPrefs}, 0);
     }
 
-    sub onsel_list_vbprefshon() {
+    sub onsel_list_vbprefshon {
         my $model = $gui{treeviewVBPrefsHON}->get_model();
         my $iter =  $gui{treeviewVBPrefsHON}->get_selection->get_selected() ? $gui{treeviewVBPrefsHON}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -504,7 +505,7 @@ sub fill_list_editstorage() {
 }
 
 # Adds a message to message log and scrolls to bottom
-sub addrow_log() {
+sub addrow_log {
     my ($msg) = @_;
     my $iter = $gui{liststoreLog}->append;
     my ($sec,$min,$hour,$mday,$mon,$year) = localtime();
@@ -530,19 +531,19 @@ sub addrow_editshared {
     else { $gui{liststoreEditShared}->set($iter, 0, $$share{name}, 1, $$share{hostPath}, 2, $access, 3, $automount, 5, $tooltip, 6, $permanent); }
 }
 
-sub addrow_info() {
+sub addrow_info {
     my $iter = $gui{liststoreInfo}->append;
     $gui{liststoreInfo}->set($iter, @_);
     return $iter;
 }
 
-sub addrow_ec() {
+sub addrow_ec {
     my $iter = $gui{liststoreEvalConfig}->append;
     $gui{liststoreEvalConfig}->set($iter, @_);
     return $iter;
 }
 
-sub getsel_combo() {
+sub getsel_combo {
     my ($widget, $col) = @_;
     my $model = $widget->get_model();
     my $iter = $widget->get_active_iter();
@@ -552,7 +553,7 @@ sub getsel_combo() {
 }
 
 # Handles single and multiple selections
-sub getsel_list_remotefiles() {
+sub getsel_list_remotefiles {
     my @filearray;
     my $model = $gui{treeviewRemoteFileChooser}->get_model();
     my @selections = $gui{treeviewRemoteFileChooser}->get_selection->get_selected_rows();
@@ -571,7 +572,7 @@ sub getsel_list_remotefiles() {
     return \@filearray;
 }
 
-sub getsel_list_editshared() {
+sub getsel_list_editshared {
     my $model = $gui{treeviewEditShared}->get_model();
     my ($path) = $gui{treeviewEditShared}->get_cursor();
     my $iter = $gui{treeviewEditShared}->get_selection->get_selected() ? $model->get_iter($path) : $model->get_iter_first();
@@ -582,7 +583,7 @@ sub getsel_list_editshared() {
     return \%hash;
 }
 
-sub getsel_list_editstorage() {
+sub getsel_list_editstorage {
     my $model = $gui{treeviewEditStor}->get_model();
     my ($path) = $gui{treeviewEditStor}->get_cursor();
     my $iter = $gui{treeviewEditStor}->get_selection->get_selected() ? $model->get_iter($path) : $model->get_iter_first();
@@ -597,9 +598,9 @@ sub getsel_list_editstorage() {
 {
     my %selected = (IUSBDeviceFilter => '');
 
-    sub getsel_list_usbfilters() { return \%selected; }
+    sub getsel_list_usbfilters { return \%selected; }
 
-    sub onsel_list_usbfilters() {
+    sub onsel_list_usbfilters {
         my $model = $gui{treeviewEditUSBFilters}->get_model();
         my $iter = $gui{treeviewEditUSBFilters}->get_selection->get_selected() ? $gui{treeviewEditUSBFilters}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -610,7 +611,7 @@ sub getsel_list_editstorage() {
         $gui{buttonEditUSBDown}->set_sensitive(1);
     }
 
-    sub fill_list_usbfilters() {
+    sub fill_list_usbfilters {
         &busy_pointer($gui{dialogEdit}, 1);
         my ($IMachine) = @_;
         $gui{buttonEditUSBEdit}->set_sensitive(0);
@@ -641,7 +642,7 @@ sub getsel_list_editstorage() {
     }
 }
 
-sub onsel_list_remotefiles() {
+sub onsel_list_remotefiles {
     my $filearrayref = &getsel_list_remotefiles();
 
     # We only care about the first file selected, and only if it's a directory
@@ -655,7 +656,7 @@ sub onsel_list_remotefiles() {
     }
 }
 
-sub onsel_list_remotefiles_single() {
+sub onsel_list_remotefiles_single {
     my $filearrayref = &getsel_list_remotefiles();
 
     # We only care about the first file selected, and only if it's a file
@@ -666,7 +667,7 @@ sub onsel_list_remotefiles_single() {
 # Activates when selecting an item in the edit storage list, could be reduced a little
 # as a lot of the options are the same for each controller but this gives flexibility
 # to expand
-sub onsel_list_editstorage() {
+sub onsel_list_editstorage {
     my $storref = &getsel_list_editstorage();
 
     if ($$storref{IsController}) {
@@ -752,10 +753,10 @@ sub onsel_list_editstorage() {
     my %selected = (IMedium => '');
 
     # Return the selected entry in the VMM floppy disk list
-    sub getsel_list_vmmfloppy() { return \%selected; }
+    sub getsel_list_vmmfloppy { return \%selected; }
 
     # Fill the floppy media list in the VMM
-    sub fill_list_vmmfloppy() {
+    sub fill_list_vmmfloppy {
         &busy_pointer($gui{dialogVMM}, 1);
         &clr_list_vmm($gui{treestoreVMMFloppy});
         my $IMediumRef = &get_all_media('Floppy');
@@ -798,7 +799,7 @@ sub onsel_list_editstorage() {
         &busy_pointer($gui{dialogVMM}, 0);
     }
 
-    sub onsel_list_vmmfloppy() {
+    sub onsel_list_vmmfloppy {
         my $model = $gui{treeviewVMMFloppy}->get_model();
         my $iter = $gui{treeviewVMMFloppy}->get_selection->get_selected() ? $gui{treeviewVMMFloppy}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -840,9 +841,7 @@ sub onsel_list_editstorage() {
             $gui{toolbuttonVMMRelease}->set_sensitive(0);
         }
 
-        $gui{labelVMMTypeField}->set_text("$selected{Type}, " . uc(IMedium_getFormat($selected{IMedium})) . ', ' . IMedium_getVariant($selected{IMedium}));
-        $gui{labelVMMAttachedToField}->set_text($gnames);
-        $gui{labelVMMLocationField}->set_text($selected{Location});
+        &set_vmm_fields($gnames, \%selected);
     }
 }
 
@@ -850,7 +849,7 @@ sub onsel_list_editstorage() {
 {
     my %selected = (IMedium => '');
 
-    sub getsel_list_vmmdvd() { return \%selected; }
+    sub getsel_list_vmmdvd { return \%selected; }
 
     # Fill the DVD media list in the VMM
     sub fill_list_vmmdvd() {
@@ -896,7 +895,7 @@ sub onsel_list_editstorage() {
         &busy_pointer($gui{dialogVMM}, 0);
     }
 
-    sub onsel_list_vmmdvd() {
+    sub onsel_list_vmmdvd {
         my $model = $gui{treeviewVMMDVD}->get_model();
         my $iter = $gui{treeviewVMMDVD}->get_selection->get_selected() ? $gui{treeviewVMMDVD}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -938,9 +937,7 @@ sub onsel_list_editstorage() {
             $gui{toolbuttonVMMRelease}->set_sensitive(0);
         }
 
-        $gui{labelVMMTypeField}->set_text("$selected{Type}, " . uc(IMedium_getFormat($selected{IMedium})) . ', ' . IMedium_getVariant($selected{IMedium}));
-        $gui{labelVMMAttachedToField}->set_text($gnames);
-        $gui{labelVMMLocationField}->set_text($selected{Location});
+        &set_vmm_fields($gnames, \%selected);
     }
 }
 
@@ -1033,10 +1030,10 @@ sub onsel_list_editstorage() {
 {
     my %selected = (IMedium => '');
 
-    sub getsel_list_vmmhd() { return \%selected; }
+    sub getsel_list_vmmhd { return \%selected; }
 
     # Fill the hard disk media list in the VMM
-    sub fill_list_vmmhd() {
+    sub fill_list_vmmhd {
         &busy_pointer($gui{dialogVMM}, 1);
         &clr_list_vmm($gui{treestoreVMMHD});
         my $IMediumRef = &get_all_media('HardDisk');
@@ -1048,7 +1045,7 @@ sub onsel_list_editstorage() {
         &busy_pointer($gui{dialogVMM}, 0);
     }
 
-    sub onsel_list_vmmhd() {
+    sub onsel_list_vmmhd {
         my $model = $gui{treeviewVMMHD}->get_model();
         my $iter = $gui{treeviewVMMHD}->get_selection->get_selected() ? $gui{treeviewVMMHD}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -1096,14 +1093,12 @@ sub onsel_list_editstorage() {
             $gui{toolbuttonVMMRelease}->set_sensitive(0);
         }
 
-        $gui{labelVMMTypeField}->set_text("$selected{Type}, " . uc(IMedium_getFormat($selected{IMedium})) . ', ' . IMedium_getVariant($selected{IMedium}));
-        $gui{labelVMMAttachedToField}->set_text($gnames);
-        $gui{labelVMMLocationField}->set_text($selected{Location});
+        set_vmm_fields($gnames, \%selected);
     }
 
     # Recurses through the media for populating the VMM media lists, including
     # identifying snapshots
-    sub recurse_hd_snapshot() {
+    sub recurse_hd_snapshot {
         my ($treestore, $IMedium, $iter) = @_;
         my %mattr = (name       => 1,
                      size       => 1,
@@ -1136,7 +1131,7 @@ sub onsel_list_editstorage() {
                                     6, $mattr{location},
                                     7, $mattr{type});
         }
-        
+
         if (($IMedium eq $selected{IMedium})) {
             $gui{treeviewVMMHD}->expand_all() if (IMedium_getParent($IMedium)); # If item is a snapshot, we need to expand the list in order for selection to work
             $gui{treeviewVMMHD}->get_selection()->select_iter($citer);
@@ -1147,7 +1142,21 @@ sub onsel_list_editstorage() {
     }
 }
 
-sub clr_list_vmm() {
+# Sets the contents of the fields in the VMM
+sub set_vmm_fields {
+    my ($gnames, $selected) = @_;
+    $gui{labelVMMTypeField}->set_text("$$selected{Type}, " . uc(IMedium_getFormat($$selected{IMedium})) . ', ' . IMedium_getVariant($$selected{IMedium}));
+    $gui{labelVMMAttachedToField}->set_text($gnames);
+    $gui{labelVMMLocationField}->set_text($$selected{Location});
+
+    if (&imedium_has_property($$selected{IMedium}, 'CRYPT/KeyId')) { $gui{labelVMMEncryptedField}->set_text(IMedium_getProperty($$selected{IMedium}, 'CRYPT/#KeyId')); }
+    else { $gui{labelVMMEncryptedField}->set_text('Not Encrypted'); }
+
+    $gui{labelVMMUUIDField}->set_text(IMedium_getId($$selected{IMedium}));
+}
+
+
+sub clr_list_vmm {
     my ($treestore) = @_;
     &vmm_sens_unselected(); # Do whenever list is cleared
     $treestore->clear();
@@ -1162,10 +1171,10 @@ sub onsel_list_shared {
 {
     my %selected = (ISnapshot => '');
 
-    sub getsel_list_snapshots() { return \%selected; }
+    sub getsel_list_snapshots { return \%selected; }
 
     # Set sensitivity when a snapshot is selected
-    sub onsel_list_snapshots() {
+    sub onsel_list_snapshots {
         my $model = $gui{treeviewSnapshots}->get_model();
         my $iter = $gui{treeviewSnapshots}->get_selection->get_selected() ? $gui{treeviewSnapshots}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
@@ -1186,7 +1195,7 @@ sub onsel_list_shared {
         }
     }
 
-    sub fill_list_snapshots() {
+    sub fill_list_snapshots {
         my $gref = &getsel_list_guest();
         &addrow_log("Fetching snapshots for $$gref{Name}...");
         &clr_list_snapshots();
@@ -1202,7 +1211,7 @@ sub onsel_list_shared {
     }
 
     # Clear snapshot list and set sensitivity
-    sub clr_list_snapshots() {
+    sub clr_list_snapshots {
         $gui{buttonRestoreSnapshot}->set_sensitive(0);
         $gui{buttonDeleteSnapshot}->set_sensitive(0);
         $gui{buttonDetailsSnapshot}->set_sensitive(0);
@@ -1210,7 +1219,7 @@ sub onsel_list_shared {
         $gui{treestoreSnapshots}->clear();
     }
 
-    sub recurse_snapshot() {
+    sub recurse_snapshot {
         my ($ISnapshot, $iter, $ISnapshot_current) = @_;
         my $citer = $gui{treestoreSnapshots}->append($iter);
         my $snapname = ISnapshot_getName($ISnapshot);
@@ -1225,7 +1234,7 @@ sub onsel_list_shared {
             my $curiter = $gui{treestoreSnapshots}->append($citer);
             $gui{treestoreSnapshots}->set($curiter, 0, '[Current State]', 1, '', 2, '', 3, $gui{img}{SnapshotCurrent});
         }
-        
+
         my @snapshots = ISnapshot_getChildren($ISnapshot);
         if (@snapshots > 0) { &recurse_snapshot($_, $citer, $ISnapshot_current) foreach (@snapshots); }
     }
@@ -1235,18 +1244,18 @@ sub onsel_list_shared {
 {
     my %selected = (Uuid => 'None'); # Initialize this element as it may be tested before the hash is fully initialized
 
-    sub makesel_list_guest() { $selected{Uuid} = $_[0]; }
+    sub makesel_list_guest { $selected{Uuid} = $_[0]; }
 
-    sub getsel_list_guest() { return \%selected; }
+    sub getsel_list_guest { return \%selected; }
 
     sub onsel_list_guest {
         &busy_pointer($gui{windowMain}, 1);
         my $model = $gui{treeviewGuest}->get_model();
         my $iter = $gui{treeviewGuest}->get_selection->get_selected() ? $gui{treeviewGuest}->get_selection->get_selected() : $model->get_iter_first();
         my @row = $model->get($iter);
-        
+
         # If there's no IMachine, it's a group so don't waste anymore time
-        if (!$row[2]) { 
+        if (!$row[2]) {
             &sens_unselected();
             $gui{treestoreDetails}->clear();
             &busy_pointer($gui{windowMain}, 0);
@@ -1301,9 +1310,11 @@ sub onsel_list_shared {
         }
         elsif ($status eq 'Paused') {
             $gui{menuitemAction}->set_sensitive(1);
+            $gui{menuitemStop}->set_sensitive(1);
             $gui{menuitemResume}->set_sensitive(1);
             $gui{menuitemRemoteDisplay}->set_sensitive(1);
             $gui{menuitemLogs}->set_sensitive(1);
+            $gui{toolbuttonStop}->set_sensitive(1);
             $gui{toolbuttonRemoteDisplay}->set_sensitive(1);
             $gui{buttonRefreshSnapshot}->set_sensitive(1);
             $gui{buttonTakeSnapshot}->set_sensitive(1);
@@ -1322,10 +1333,11 @@ sub onsel_list_shared {
             $gui{toolbuttonSettings}->set_sensitive(1);
             $gui{buttonRefreshSnapshot}->set_sensitive(1);
             $gui{buttonTakeSnapshot}->set_sensitive(1);
-            $gui{menuitemHotPlugCPU}->set_sensitive(1) if (&bl(IMachine_getCPUHotPlugEnabled($selected{IMachine})));
+            $gui{menuitemHotPlugCPU}->set_sensitive(0);
         }
         elsif ($status eq 'Stuck') {
                &sens_unselected();
+               $gui{menuitemStop}->set_sensitive(1);
                $gui{toolbuttonStop}->set_sensitive(1);
         }
         else { &sens_unselected(); }
@@ -1333,9 +1345,9 @@ sub onsel_list_shared {
         &busy_pointer($gui{windowMain}, 0);
     }
 
-    sub add_guest_group() {
+    sub add_guest_group {
         my ($node, $name, $piter) = @_;
-        
+
         if (defined($$node{$name})) { return $$node{$name}{node}, $$node{$name}{iter}; }
         else {
             my $citer = $gui{treestoreGuest}->append($piter);
@@ -1350,7 +1362,7 @@ sub onsel_list_shared {
     }
 
     # Populates the list of available guests
-    sub fill_list_guest() {
+    sub fill_list_guest {
         my $osver = &osver();
         my %grouptree;
         &addrow_log("Fetching guest list from $endpoint...");
@@ -1372,7 +1384,7 @@ sub onsel_list_shared {
                 $group =~ s/^\///; # Leading / is optional so always remove or simplicity
                 my @components = split('/', $group);
                 my $piter = undef;
-                ($node, $piter) = &add_guest_group($node, $_, $piter) foreach (@components); 
+                ($node, $piter) = &add_guest_group($node, $_, $piter) foreach (@components);
                 $guestlist{$machine}{iter} = $piter;
             }
             else { $inaccessible = 1; }
@@ -1416,7 +1428,7 @@ sub onsel_list_shared {
         &update_server_membar();
     }
 
-    sub clr_list_guest() {
+    sub clr_list_guest {
         &sens_unselected();
         $gui{treestoreGuest}->clear();
         $gui{treestoreDetails}->clear();
