@@ -29,7 +29,7 @@ elsif ($cmdopts{H}) { &show_dialog_connect('AUTO'); }
 $0 = 'RemoteBox VirtualBox Client';
 Gtk2->main;
 
-sub quit_remotebox() {
+sub quit_remotebox {
     &save_window_pos('windowMain'); # Also saves the main preferences
     &virtualbox_logoff();
 
@@ -44,27 +44,27 @@ sub quit_remotebox() {
 }
 
 # Attempts to logon or fails with a dialog
-sub virtualbox_logon() {
+sub virtualbox_logon {
     my ($url, $user, $password) = @_;
     &virtualbox_logoff(); # Ensure we disconnect from an existing connection
     $endpoint = $url;
-
+    $fault = \&vboxlogonerror;
     $gui{websn} = IWebsessionManager_logon($user, $password);
-    
+
     if ($gui{websn}) {
         $fault = \&vboxerror; # Install the fault capture
         $gui{heartbeat} = Glib::Timeout->add(58000, \&heartbeat) if ($prefs{HEARTBEAT}); # Install heartbeat if requested
         $gui{servermem} = Glib::Timeout->add(300000, \&update_server_membar);
         return 1;
     }
-    else {
-        &show_err_msg('connect', " ($url)");
-        return 0;
-    }
+    #else {
+    #    #&show_err_msg('connect', " ($url)");
+    #    return 0;
+    #}
 }
 
 # Logoff and perform various necessary cleanups
-sub virtualbox_logoff() {
+sub virtualbox_logoff {
     my ($closewin) = @_;
     $fault = sub{}; # Disable fault capture. Protection against infinite loops
     Glib::Source->remove($gui{heartbeat}) if ($gui{heartbeat}); # Remove any heartbeat timers
@@ -91,7 +91,7 @@ sub virtualbox_logoff() {
 }
 
 # Be careful with use of $vhost in this sub!
-sub show_dialog_connect() {
+sub show_dialog_connect {
     my ($widget) = @_;
     my $response = 'cancel';
 
@@ -140,7 +140,7 @@ sub show_dialog_connect() {
         my $url = $gui{comboboxentryConnectURL}->get_active_text();
         my $user = $gui{comboboxentryConnectUser}->get_active_text();
         $url = $endpoint if (!$url);
-        $url =~ s/(\/)+$//g; # Remove all trailing 
+        $url =~ s/(\/)+$//g; # Remove all trailing
         $url = "http://$url" if ($url !~ m/^.+:\/\//);
         $url = "$url:18083" if ($url !~ m/:\d+$/);
 
@@ -177,13 +177,13 @@ sub show_dialog_connect() {
     }
 }
 
-sub show_dialog_about() {
+sub show_dialog_about {
     $gui{aboutdialog}->run;
     $gui{aboutdialog}->hide;
 }
 
 # Shows the custom video hint dialog
-sub show_dialog_videohint() {
+sub show_dialog_videohint {
     $gui{spinbuttonCustomVideoW}->set_value($prefs{AUTOHINTDISPX});
     $gui{spinbuttonCustomVideoH}->set_value($prefs{AUTOHINTDISPY});
     $gui{dialogCustomVideo}->run;
@@ -197,7 +197,7 @@ sub show_dialog_videohint() {
 }
 
 # Shows a dialog with basic information about the VirtualBox server
-sub show_dialog_serverinfo() {
+sub show_dialog_serverinfo {
     &fill_list_serverinfo();
     $gui{dialogInfo}->set_title('Server Information');
     $gui{dialogInfo}->run;
@@ -205,7 +205,7 @@ sub show_dialog_serverinfo() {
 }
 
 # Displays a dialog with the contents of the logs for a specific guest
-sub show_dialog_log() {
+sub show_dialog_log {
     my ($widget) = @_;
     my $gref = &getsel_list_guest();
     &fill_list_log($$gref{IMachine});
@@ -223,6 +223,31 @@ sub show_dialog_exportappl {
     $gui{entryExportApplName}->set_text($$gref{Name});
     $gui{textbufferExportApplDescription}->set_text(IMachine_getDescription($$gref{IMachine}));
 
+    # Determine if any media are USB attached as they are not supported by Appliances and
+    # whether any media encrypted
+    my @IMediumAttachment = IMachine_getMediumAttachments($$gref{IMachine});
+    my %used_key_ids; # Key IDs can only be asked for once, we keep a used list here
+
+    foreach my $attach (@IMediumAttachment) {
+        my $IStorageController = IMachine_getStorageControllerByName($$gref{IMachine}, $$attach{controller});
+
+        if (IStorageController_getBus($IStorageController) eq 'USB') {
+            &show_err_msg('exportapplusb');
+            return;
+        }
+
+        next if (!$$attach{medium}); # Empty DVD drive etc
+
+        if (&imedium_has_property($$attach{medium}, 'CRYPT/KeyStore')) {
+            my $keyid = IMedium_getProperty($$attach{medium}, 'CRYPT/KeyId');
+            if (!$used_key_ids{$keyid}) {
+                my $passwd = &show_dialog_decpasswd($$attach{medium}, $keyid);
+                if ($passwd) { $used_key_ids{$keyid} = $passwd; }
+                else { return; }
+            }
+        }
+    }
+
     do {
         my $response = $gui{dialogExportAppl}->run;
 
@@ -235,6 +260,11 @@ sub show_dialog_exportappl {
                 my $location = $gui{entryExportApplFile}->get_text();
                 $location .= '.ova' if ($location !~ m/.ovf$/i and $location !~ m/.ova$/i);
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
+
+                foreach my $key (keys(%used_key_ids)) {
+                    IAppliance_addPasswords($IAppliance, $key, $used_key_ids{$key});
+                }
+
                 my $IVirtualSystemDescription = IMachine_exportTo($$gref{IMachine}, $IAppliance, $location);
                 IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Name', $gui{entryExportApplName}->get_text(), '');
                 IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Product', $gui{entryExportApplProduct}->get_text(), '');
@@ -278,7 +308,7 @@ sub show_dialog_snapshotdetails {
     }
 }
 
-sub show_dialog_snapshot() {
+sub show_dialog_snapshot {
     my ($widget) = @_; # Need to reuse dialog for snapshot details
     $gui{entrySnapshotName}->set_text('Snapshot');
     $gui{textbufferSnapshotDescription}->set_text('');
@@ -293,10 +323,10 @@ sub show_dialog_snapshot() {
 }
 
 # Discards the saved execution state for a guest
-sub discard_saved_state() {
+sub discard_saved_state {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
-    
+
     IMachine_discardSavedState($$sref{IMachine}, 'true');
     &fill_list_guest();
     &addrow_log("Discarded saved execution state of $$gref{Name}.");
@@ -306,7 +336,7 @@ sub discard_saved_state() {
 }
 
 # Performs a reset of the guest
-sub reset_guest() {
+sub reset_guest {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -319,14 +349,14 @@ sub reset_guest() {
 }
 
 # Stops the guest
-sub stop_guest() {
+sub stop_guest {
     if ($prefs{STOPTYPE} eq 'ACPI') { &stop_guest_acpi(); }
     elsif ($prefs{STOPTYPE} eq 'STATE') { &stop_guest_savestate(); }
     else { &stop_guest_poweroff(); }
 }
 
 # Stops a guest by issuing a hard poweroff
-sub stop_guest_poweroff() {
+sub stop_guest_poweroff {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -346,7 +376,7 @@ sub stop_guest_poweroff() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub stop_guest_acpi() {
+sub stop_guest_acpi {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -361,12 +391,12 @@ sub stop_guest_acpi() {
 }
 
 # Stops a guest and save it's execution state
-sub stop_guest_savestate() {
+sub stop_guest_savestate {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
     if ($$sref{Lock} eq 'Shared') {
-        
+
         if (my $IProgress = IMachine_saveState($$sref{IMachine})) { # Not cancellable
             &show_progress_window($IProgress, "Saving guest execution state of $$gref{Name}");
             &fill_list_guest();
@@ -380,7 +410,7 @@ sub stop_guest_savestate() {
 }
 
 # Pauses the execution of the guest
-sub pause_guest() {
+sub pause_guest {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -393,7 +423,7 @@ sub pause_guest() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub resume_guest() {
+sub resume_guest {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -406,7 +436,7 @@ sub resume_guest() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub start_guest() {
+sub start_guest {
     my $gref = &getsel_list_guest();
     my $ISession = IWebsessionManager_getSessionObject($gui{websn});
     my $IProgress = IMachine_launchVMProcess($$gref{IMachine}, $ISession, 'headless', "");
@@ -415,7 +445,7 @@ sub start_guest() {
     if ($IProgress) { # Is Cancellable
         my $resultcode = &show_progress_window($IProgress, "Starting guest $$gref{Name}");
 
-        if (IProgress_getCanceled($IProgress) eq 'true') { &addrow_log("Cancelled staring guest $$gref{Name}"); }
+        if (IProgress_getCanceled($IProgress) eq 'true') { &addrow_log("Cancelled starting guest $$gref{Name}"); }
         elsif ( $resultcode != 0) {
             my $IVirtualBoxErrorInfo = IProgress_getErrorInfo($IProgress);
             &show_err_msg('startguest', "Guest: $$gref{Name}\nCode: $resultcode\nError:\n" . IVirtualBoxErrorInfo_getText($IVirtualBoxErrorInfo));
@@ -423,17 +453,50 @@ sub start_guest() {
         else {
             $started = 1;
             &addrow_log("Start signal sent to $$gref{Name}.");
+
+            # Determine if we have anything encrypted
+            my @IMediumAttachment = IMachine_getMediumAttachments($$gref{IMachine});
+            my %used_key_ids; # Key IDs can only be asked for once, we keep a used list here
+
+            # Determine if any media are encrypted and prompt for the password
+            foreach my $attach (@IMediumAttachment) {
+                next if ($$attach{type} ne 'HardDisk');
+
+                if (&imedium_has_property($$attach{medium}, 'CRYPT/KeyStore')) {
+                    my $keyid = IMedium_getProperty($$attach{medium}, 'CRYPT/KeyId');
+                    if (!$used_key_ids{$keyid}) {
+                        my $passwd = &show_dialog_decpasswd($$attach{medium}, $keyid);
+
+                        if ($passwd) {
+                            my $gref = &getsel_list_guest();
+                            my $sref = &get_session($$gref{IMachine});
+
+                            if ($$sref{Lock} eq 'Shared') {
+                                my $IConsole = ISession_getConsole($$sref{ISession});
+                                IConsole_addDiskEncryptionPassword($IConsole, $keyid, $passwd, 0);
+                            }
+
+                            ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
+                            $used_key_ids{$keyid} = $passwd;
+                        }
+                        else {
+                            $started = 0;
+                            &stop_guest_poweroff();
+                        }
+                    }
+                }
+            }
         }
     }
     else { &show_err_msg('sessionopen', " ($$gref{Name})"); }
 
     ISession_unlockMachine($ISession) if (ISession_getState($ISession) ne 'Unlocked');
-    &open_remote_display() if ($prefs{RDPAUTOOPEN} and $started);   
-    &fill_list_guest();
+    &open_remote_display() if ($prefs{RDPAUTOOPEN} and $started);
+    &fill_list_guest() if ($started);
 }
 
 # Removes a guest, optionally deleting associated files
-sub remove_guest() {
+sub remove_guest {
     my $gref = &getsel_list_guest();
     my $response = $gui{dialogRemoveGuest}->run;
     $gui{dialogRemoveGuest}->hide;
@@ -460,7 +523,7 @@ sub remove_guest() {
 }
 
 # Restores a guest to a snapshot state
-sub restore_snapshot() {
+sub restore_snapshot {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -477,7 +540,7 @@ sub restore_snapshot() {
 }
 
 # Deletes a guest snapshot
-sub delete_snapshot() {
+sub delete_snapshot {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -499,7 +562,7 @@ sub delete_snapshot() {
 }
 
 # Takes a snapshot of a guest
-sub take_snapshot() {
+sub take_snapshot {
     my ($name, $description) = @_;
     $name = 'Snapshot' if (!$name);
     my $gref = &getsel_list_guest();
@@ -517,7 +580,7 @@ sub take_snapshot() {
 }
 
 # Attempts to open the remote display by calling the RDP client
-sub open_remote_display() {
+sub open_remote_display {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -568,15 +631,15 @@ sub open_remote_display() {
 {
     my %vhost;
 
-    sub vhost() {
+    sub vhost {
         &init_vhost() if (!%vhost);
         return \%vhost;
     }
 
     # Invalidate vhost to force a new retrieve
-    sub clr_vhost() { %vhost = (); }
+    sub clr_vhost { %vhost = (); }
 
-    sub init_vhost() {
+    sub init_vhost {
         my $IHost = IVirtualBox_getHost($gui{websn});
         my $ISystemProperties = IVirtualBox_getSystemProperties($gui{websn});
         %vhost = (ISystemProperties => $ISystemProperties,
@@ -628,19 +691,19 @@ sub open_remote_display() {
     my %osfam;
     my %osver;
 
-    sub osfam() {
+    sub osfam {
         &init_oslist() if (!%osfam);
         return \%osfam;
     }
 
-    sub osver() {
+    sub osver {
         &init_oslist() if (!%osver);
         return \%osver;
     }
 
-    sub osfamver() { return &osfam(), &osver(); }
+    sub osfamver { return &osfam(), &osver(); }
 
-    sub init_oslist() {
+    sub init_oslist {
         my @IGuestOSType = IVirtualBox_getGuestOSTypes($gui{websn});
         foreach my $type (@IGuestOSType) {
             if (!defined($osfam{$$type{familyId}})) {
@@ -684,7 +747,7 @@ sub open_remote_display() {
 }
 
 # Displays a popup machine menu on the guest list when the right mouse button is pressed
-sub show_rmb_menu() {
+sub show_rmb_menu {
     my ($widget, $event) = @_;
 
     # Check if it's the RMB otherwise do nothing
@@ -706,7 +769,7 @@ sub show_rmb_menu() {
 }
 
 # Called when parent DVD menu is highlighted. Cheaper than calling each time main menu is opened
-sub fill_menu_dvd() {
+sub fill_menu_dvd {
     my $vhost = &vhost();
     my $dvdmenu = Gtk2::Menu->new();
     $gui{menuitemDVD}->set_submenu(undef); # Help garbage collection
@@ -742,7 +805,7 @@ sub fill_menu_dvd() {
 }
 
 # Called when parent USB menu is highlighted. Cheaper than calling each time machine menu is opened
-sub fill_menu_usb() {
+sub fill_menu_usb {
     my %connected;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -774,7 +837,7 @@ sub fill_menu_usb() {
 }
 
 # Fills the menu with the number of hot pluggable CPUs
-sub fill_menu_cpu() {
+sub fill_menu_cpu {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -788,7 +851,7 @@ sub fill_menu_cpu() {
         my $item = Gtk2::CheckMenuItem->new_with_label('vCPU 0');
         $item->set_active(1);
         $item->set_sensitive(0);
-        $item->set_tooltip_text('vCPU 0 is never hot pluggabe');
+        $item->set_tooltip_text('vCPU 0 is never hot pluggable');
         $cpumenu->append($item);
         $item->show();
 
@@ -805,7 +868,7 @@ sub fill_menu_cpu() {
 }
 
 # Attaches or detaches a processor whilst the guest is online
-sub mount_cpu_online() {
+sub mount_cpu_online {
     my ($widget, $cpunum) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -828,7 +891,7 @@ sub mount_cpu_online() {
 }
 
 # Attaches or detaches a USB device whilst the guest is online
-sub mount_usb_online() {
+sub mount_usb_online {
     my ($widget, $dataref) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -852,7 +915,7 @@ sub mount_usb_online() {
 }
 
 # Called when parent Floppy menu is highlighted. Cheaper than calling each time machine menu is opened
-sub fill_menu_floppy() {
+sub fill_menu_floppy {
     my $vhost = &vhost();
     my $floppymenu = Gtk2::Menu->new();
     $gui{menuitemFloppy}->set_submenu(undef); # Help garbage collection
@@ -888,7 +951,7 @@ sub fill_menu_floppy() {
 }
 
 # Inserts a DVD/CD whilst the guest is online and running
-sub mount_dvd_online() {
+sub mount_dvd_online {
     my ($widget, $IMedium) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -908,7 +971,7 @@ sub mount_dvd_online() {
 }
 
 # Inserts a floppy disk image whilst the guest is online
-sub mount_floppy_online() {
+sub mount_floppy_online {
     my ($widget, $IMedium) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -927,7 +990,7 @@ sub mount_floppy_online() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub keyboard_CAD() {
+sub keyboard_CAD {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -940,7 +1003,7 @@ sub keyboard_CAD() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub keyboard_send() {
+sub keyboard_send {
     my ($widget) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -1053,7 +1116,7 @@ sub keyboard_send() {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
-sub update_vidmeminfo() {
+sub update_vidmeminfo {
     my $w = int($gui{spinbuttonCustomVideoW}->get_value());
     my $h = int($gui{spinbuttonCustomVideoH}->get_value());
     my $d = &getsel_combo($gui{comboboxCustomVideoD}, 1);
@@ -1063,7 +1126,7 @@ sub update_vidmeminfo() {
 }
 
 # Sends a video mode hint to the guest
-sub send_video_hint() {
+sub send_video_hint {
     my ($widget) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -1089,7 +1152,7 @@ sub send_video_hint() {
 }
 
 # Return a hash reference with name as key. Useful for sorting
-sub get_all_media() {
+sub get_all_media {
     my ($type) = @_;
     my @IMedium;
     my %media;
@@ -1102,8 +1165,10 @@ sub get_all_media() {
     return \%media;
 }
 
+
+
 # Return an appropriate session
-sub get_session() {
+sub get_session {
     my ($IMachine) = @_;
     my $ISession = IWebsessionManager_getSessionObject($gui{websn});
     my %state = (Lock     => 'None',
@@ -1130,10 +1195,36 @@ sub get_session() {
     return \%state;
 }
 
+# Encrypts a hard disk image. *MUST* only be given hard disk images
+sub encrypt_disk {
+    my ($IMedium, $currentpasswd, $cipher, $newpasswd, $passwdid) = @_;
+    my $name = IMedium_getName($IMedium);
+
+    # Not allowed to have children
+    if (IMedium_getChildren($IMedium)) {
+        &addrow_log("The Medium $name cannot be encrypted because it has child media.");
+        return 1;
+    }
+
+    # Only allowed to be attached to 1 machine or fewer
+    my @mids = IMedium_getMachineIds($IMedium);
+
+    if (scalar(@mids) > 1) {
+        &addrow_log("The Medium $name cannot be encrypted because it is attached to more than 1 guest");
+        return 1;
+    }
+
+    my $IProgress = IMedium_changeEncryption($IMedium, $currentpasswd, $cipher, $newpasswd, $passwdid);
+    &addrow_log("Enrypting the disk image $name with $cipher.");
+    &show_progress_window($IProgress, "Encrypting Disk Image $name");
+
+    return 0;
+}
+
 # Expects a hash reference as an input and populates the hash with IMedium
 # attributes, if that attribute has already been defined. The second argument
 # is the IMedium virtualbox reference
-sub get_imedium_attrs() {
+sub get_imedium_attrs {
     my ($href, $IMedium) = @_;
     return unless $IMedium;
     $$href{IMedium} = $IMedium; # For convenience
@@ -1148,10 +1239,19 @@ sub get_imedium_attrs() {
     $$href{type} = IMedium_getType($IMedium) if ($$href{type}); # Get the medium type
 }
 
+# Returns whether the IMedium object has a particular property.
+# uses getProperties to avoid VirtualBox from issuing an error when
+# other methods would.
+sub imedium_has_property {
+    my ($IMedium, $property) = @_;
+    my @properties = IMedium_getProperties($IMedium, undef); # Note, SDK states second parameter is ignored
+    return (grep($property, @properties));
+}
+
 # Expects a hash reference as an input and populates the hash with IStorageController
 # attributes, if that attribute has already been defined. The second argument
 # is the IStorageController virtualbox reference
-sub get_icontroller_attrs() {
+sub get_icontroller_attrs {
     my ($href, $IStorageController) = @_;
     return unless $IStorageController;
     $$href{IStorageController} = $IStorageController; # For Convenience
@@ -1161,7 +1261,7 @@ sub get_icontroller_attrs() {
 }
 
 # Set sensitivity based on connection state
-sub sens_connect() {
+sub sens_connect {
     my ($state) = @_;
     $gui{menuitemNew}->set_sensitive($state);
     $gui{menuitemAdd}->set_sensitive($state);
@@ -1210,14 +1310,14 @@ sub sens_unselected {
 }
 
 # Resets the guest icon back to the default
-sub reset_icon() {
+sub reset_icon {
     my $gref = &getsel_list_guest();
     unlink("$gui{THUMBDIR}/$$gref{Uuid}.png") if (-e "$gui{THUMBDIR}/$$gref{Uuid}.png");
     &fill_list_guest();
 }
 
 # Takes a PNG screenshot of the guest
-sub screenshot() {
+sub screenshot {
     my ($widget) = @_;
 
     my $gref = &getsel_list_guest();
@@ -1253,7 +1353,7 @@ sub screenshot() {
 }
 
 # Sets the guest icon to a screenshot of the guest
-sub screenshot_to_icon() {
+sub screenshot_to_icon {
     my ($widget) = @_;
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
@@ -1309,14 +1409,14 @@ sub show_dialog_importappl {
                 &addrow_log("Importing appliance from $appliancefile");
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
                 my $IProgress = IAppliance_read($IAppliance, $appliancefile);
-        
+
                 if ($IProgress) {
                     &show_progress_window($IProgress, 'Reading Appliance');
                     IAppliance_interpret($IAppliance);
                     my $warnings = IAppliance_getWarnings($IAppliance);
                     &addrow_log("Import warnings: $warnings") if ($warnings);
                     $IProgress = IAppliance_importMachines($IAppliance, $importopts);
-            
+
                     if ($IProgress) {
                         &show_progress_window($IProgress, 'Importing Appliance') if ($IProgress);
                         my @appluuid = IAppliance_getMachines($IAppliance);
@@ -1329,7 +1429,7 @@ sub show_dialog_importappl {
                     }
                     else { &show_err_msg('applimport', "($appliancefile)"); }
                 }
-                else { &show_err_msg('applimport', "($appliancefile)"); } 
+                else { &show_err_msg('applimport', "($appliancefile)"); }
             }
         }
         else { $gui{dialogImportAppl}->hide; }
@@ -1337,6 +1437,22 @@ sub show_dialog_importappl {
     } until (!$gui{dialogImportAppl}->visible());
 }
 
+# Displays the dialog for entering a decryption password
+sub show_dialog_decpasswd {
+    my ($IMedium, $keyid) = @_;
+    my $passwd;
+    $gui{labelEnterDecPasswdID}->set_text("Key ID: $keyid");
+    $gui{labelEnterDecPasswdName}->set_text("Disk Name: " . IMedium_getName($IMedium));
+
+    my $response = $gui{dialogEnterDecPasswd}->run;
+    $gui{dialogEnterDecPasswd}->hide;
+
+    if ($response eq 'ok') { $passwd = $gui{entryEnterDecPasswd}->get_text(); }
+
+    return $passwd;
+}
+
+
 # Displays the dialog for setting a guests group
 sub show_dialog_group {
     my $gref = &getsel_list_guest();
@@ -1394,7 +1510,7 @@ sub update_server_membar {
 
 # Shows the PDF manual when the option is selected. Uses the user's default
 # PDF reader via xdg-open on UNIX/BSD/Linux or open on Mac OS X
-sub show_manual() {
+sub show_manual {
     if ($^O =~ m/darwin/i) { system(qq[open "$docdir/remotebox.pdf" &]); }
     elsif ($^O =~ m/MSWin/) {
         my $windocdir = File::Spec::Win32->canonpath($docdir);
@@ -1410,11 +1526,11 @@ sub extended_details {
     # Force a refresh if there's a selected guest
     my $model = $gui{treeviewGuest}->get_model();
     my $iter = $gui{treeviewGuest}->get_selection->get_selected() ? $gui{treeviewGuest}->get_selection->get_selected() : 0;
-    &onsel_list_guest() if ($iter); 
+    &onsel_list_guest() if ($iter);
 }
 
 # Converts bytes into a human readable format with unit
-sub bytesToX() {
+sub bytesToX {
     my ($bytes) = @_;
     my ($unit, $val);
 
@@ -1440,4 +1556,4 @@ sub bytesToX() {
     return $val;
 }
 
-1;
\ No newline at end of file
+1;
