@@ -130,7 +130,7 @@ sub show_dialog_clone {
 
         if ($response eq 'ok') {
             # No validation needed for other entries
-            if (!$gui{entryCloneName}->get_text()) { &show_err_msg('invalidname'); } 
+            if (!$gui{entryCloneName}->get_text()) { &show_err_msg('invalidname'); }
             else {
                 $gui{dialogClone}->hide;
                 my $clonetype = 'Full'; # Defaults to Full
@@ -138,7 +138,7 @@ sub show_dialog_clone {
 
                 if ($gui{comboboxCloneType}->get_active() == 2) { $clonetype = 'Link'; }
                 elsif ($gui{comboboxCloneType}->get_active() == 1) { $clonetype = 'Current'; }
-        
+
                 &create_new_clone($gref, $gui{entryCloneName}->get_text(), $clonetype, $newmacs);
                 &fill_list_guest();
             }
@@ -221,7 +221,7 @@ sub create_new_clone {
         IManagedObjectRef_release($cloneIMachine);
         $cloneIMachine = undef;
     }
-    else {  
+    else {
         # Regenerate the MACs if the option has been selected
         if ($newmacs) {
             foreach (0..($$vhost{maxnet}-1)) {
@@ -333,7 +333,7 @@ sub newgen_osfam {
     {
         my $iter = $gui{liststoreNewOSVer}->append();
         $gui{liststoreNewOSVer}->set($iter, 0, $$osver{$ver}{description}, 1, $ver, 2, $$osver{$ver}{icon});
-        $combover->set_active_iter($iter) if ($ver eq 'WindowsXP' | $ver eq 'Ubuntu' | $ver eq 'Solaris');
+        $combover->set_active_iter($iter) if ($ver eq 'Windows7_64' | $ver eq 'Ubuntu_64' | $ver eq 'Solaris11_64');
     }
 
     $combover->set_active(0) if ($combover->get_active() == -1);
@@ -413,4 +413,4 @@ sub sens_hdformatchanged {
     }
 }
 
-1;
\ No newline at end of file
+1;
