@@ -96,7 +96,7 @@ sub show_dialog_editnat {
 
     do {
         my $response = $gui{dialogNATDetails}->run;
- 
+
         if ($response eq 'ok') {
             # Other entries do not require validation
             if (!$gui{entryvbprefsNATName}->get_text()) { &show_err_msg('invalidname', '(Network Name)'); }
@@ -131,7 +131,7 @@ sub show_dialog_pf4 {
             else {
                 $gui{dialogPFIPv4}->hide;
                 my $natref = &getsel_list_vbprefsnat();
-                INATNetwork_addPortForwardRule($$natref{INATNetwork}, 0, 
+                INATNetwork_addPortForwardRule($$natref{INATNetwork}, 0,
                                        $gui{entryPFIPv4Name}->get_text(),
                                        &getsel_combo($gui{comboboxPFIPv4Protocol}, 1),
                                        $gui{entryPFIPv4HostIP}->get_text(),
@@ -162,7 +162,7 @@ sub show_dialog_pf6 {
             else {
                 $gui{dialogPFIPv6}->hide;
                 my $natref = &getsel_list_vbprefsnat();
-                INATNetwork_addPortForwardRule($$natref{INATNetwork}, 1, 
+                INATNetwork_addPortForwardRule($$natref{INATNetwork}, 1,
                                        $gui{entryPFIPv6Name}->get_text(),
                                        &getsel_combo($gui{comboboxPFIPv6Protocol}, 1),
                                        $gui{entryPFIPv6HostIP}->get_text(),
@@ -230,7 +230,7 @@ sub show_dialog_prefs {
 }
 
 # Clears the connection history so the connect dialog will be empty
-sub show_dialog_clearhistory() {
+sub show_dialog_clearhistory {
     my $response = $gui{messagedialogClearHistory}->run;
     $gui{messagedialogClearHistory}->hide;
 
@@ -434,4 +434,4 @@ sub set_rdppreset {
     elsif ($widget eq $gui{menuitemrdppreset4}) { $gui{entryPrefsRDPClient}->set_text('mstsc /w:%X /h:%Y /v:%h:%p >nul'); }
 }
 
-1;
\ No newline at end of file
+1;
